#!/usr/bin/ruby
# coding: utf-8

include Math
require "narray"
require './planetorbit'
require './solar_system_fig'
require './solar_system_param'


# ep : the epoch 1990.0, epoch 1990.0 probably means 1990/01/00.
#sEpoch1990 = 2447891.50
#
sYYYY = 1990
sMM   =    1
sDD   =    0
sJDEpoch1990 = ac2jd( sYYYY, sMM, sDD )


if ARGV.size == 0 then
  iws      = 1
  sFigF    = "dcl"

  sFigSize = 6.0

  sCurDate = Time.now
  sYYYY = sCurDate.year
  sMM   = sCurDate.month
  sDD   = sCurDate.day + ( sCurDate.hour + ( sCurDate.min + sCurDate.sec / 60.0 ) / 60.0 ) / 24.0
elsif ARGV.size == 1 then
  iws      = 1
  sFigFN   = "dcl"

  sFigSize = 6.0

  #print "Input date (YYYY/MM/DD): "
  #sDate = gets.split("/")
  sDate = ARGV[0].split("/")
  sYYYY = sDate[0].to_i
  sMM   = sDate[1].to_i
  sDD   = sDate[2].to_i
elsif ARGV.size > 1 then
  iws      = 2
  sFigFN   = ARGV[0]

  sFigSize = ARGV[1].to_f

  #print "Input date (YYYY/MM/DD): "
  #sDate = gets.split("/")
  sDate = ARGV[2].split("/")
  sYYYY = sDate[0].to_i
  sMM   = sDate[1].to_i
  sDD   = sDate[2].to_i
end

sJD0  = ac2jd( sYYYY, sMM, sDD )


NOrbitDiv = 361
aa_EclX = NArray.float(NOrbitDiv,NPlanet)
aa_EclY = NArray.float(NOrbitDiv,NPlanet)
aa_EclZ = NArray.float(NOrbitDiv,NPlanet)

for iPlanet in 0..(NPlanet-1)
  sSMAxis       = A_SMAxis[iPlanet]
  sEccen        = A_Eccen[iPlanet]
  sPerLon       = A_PerLon[iPlanet]
#sSecInAYear = tryear[iPlanet] * 365.0 * ( 60.0 * 60.0 * 24.0 )
  sSecInAYear   = A_TrYear[iPlanet] * 365.242191 * ( 60.0 * 60.0 * 24.0 )
  sEpsOrb       = A_Obliq[iPlanet]
  sPerLs        = A_PerLs[iPlanet]
  sMLonAtEpoch  = A_MLonEp[iPlanet]
  sOrbInc       = A_OrbInc[iPlanet]
  sAscLon       = A_AscLon[iPlanet]

  for l in 0..(NOrbitDiv-1)
    sJD = sJD0 + sSecInAYear / ( 60*60*24 ) / (NOrbitDiv-1) * l
    sSecFromEpoch = ( sJD - sJDEpoch1990 ) * ( 60.0 * 60.0 * 24.0 )

    #sHeldis, sSinDel, sLs = planetorbit( sSMAxis, sEccen, sPerLon, sSecInAYear, sEpsOrb, sPerLs, sMLonAtEpoch, sSecFromEpoch )
    sHeldis, sSinDel, sLs, sEclLon, sEclLat = planetorbitWithLonLat( sSMAxis, sEccen, sPerLon, sSecInAYear, sEpsOrb, sPerLs, sMLonAtEpoch, sSecFromEpoch, sOrbInc, sAscLon )

    aa_EclX[l,iPlanet] = sHeldis * cos( sEclLat * PI/180.0 ) * cos( sEclLon * PI/180.0 )
    aa_EclY[l,iPlanet] = sHeldis * cos( sEclLat * PI/180.0 ) * sin( sEclLon * PI/180.0 )
    aa_EclZ[l,iPlanet] = sHeldis * sin( sEclLat * PI/180.0 )

  end
end

draw_preparation( iws, sFigFN )
title = "Planetary position at " + sYYYY.to_s + "/" + sMM.to_s + "/" + sDD.to_s + "\n"
draw_orbit( title, sFigSize, aa_EclX, aa_EclY, A_PlaIni )
draw_finish
